# eric7.Plugins.VcsPlugins.vcsMercurial.HgDiffDialog

Module implementing a dialog to show the output of the hg diff command process.

### Global Attributes

None

### Classes

HgDiffDialog | Class implementing a dialog to show the output of the hg diff command process.

### Functions

None

## HgDiffDialog

Class implementing a dialog to show the output of the hg diff command process.

### Derived from

QWidget, Ui_HgDiffDialog

### Class Attributes

None

### Class Methods

None

### Methods

HgDiffDialog | Constructor
__generatorFinished | Private slot connected to the finished signal.
closeEvent | Protected slot implementing a close event handler.
on_buttonBox_clicked | Private slot called by a button of the button box clicked.
on_filesCombo_activated | Private slot to handle the selection of a file.
on_refreshButton_clicked | Private slot to refresh the display.
on_saveButton_clicked | Private slot to handle the Save button press.
start | Public slot to start the hg diff command.

### Static Methods

None

#### HgDiffDialog (Constructor)

HgDiffDialog(vcs, parent=None)

Constructor

vcs
  reference to the vcs object
parent
  parent widget (QWidget)

#### HgDiffDialog.__generatorFinished

__generatorFinished()

Private slot connected to the finished signal.

#### HgDiffDialog.closeEvent

closeEvent(e)

Protected slot implementing a close event handler.

e
  close event (QCloseEvent)

#### HgDiffDialog.on_buttonBox_clicked

on_buttonBox_clicked(button)

Private slot called by a button of the button box clicked.

button
  button that was clicked (QAbstractButton)

#### HgDiffDialog.on_filesCombo_activated

on_filesCombo_activated(index)

Private slot to handle the selection of a file.

index
  activated row (integer)

#### HgDiffDialog.on_refreshButton_clicked

on_refreshButton_clicked()

Private slot to refresh the display.

#### HgDiffDialog.on_saveButton_clicked

on_saveButton_clicked()

Private slot to handle the Save button press.

It saves the diff shown in the dialog to a file in the local filesystem.

#### HgDiffDialog.start

start(fn, versions=None, bundle=None, qdiff=False, refreshable=False)

Public slot to start the hg diff command.

fn
  filename to be diffed (string)
versions
  list of versions to be diffed (list of up to 2 strings or None)
bundle
  name of a bundle file (string)
qdiff
  flag indicating qdiff command shall be used (boolean)
refreshable
  flag indicating a refreshable diff (boolean)

Up